@@ -13,7 +13,7 @@ use Sub::Name ();
 package Kavorka;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_07';
+our $VERSION   = '0.000_08';
 
 our @ISA         = qw( Exporter::Tiny );
 our @EXPORT      = qw( fun method );
@@ -81,7 +81,7 @@ sub _exporter_expand_sub
 	
 	Parse::Keyword::install_keyword_handler(
 		$code => sub {
-			my $subroutine = $implementation->parse;
+			my $subroutine = $implementation->parse(keyword => $name);
 			return (
 				sub { ($subroutine, $args) },
 				!! $subroutine->declared_name,
@@ -549,12 +549,14 @@ The coderef for any sub created by Kavorka can be passed to the
 C<< Kavorka->info >> method. This returns a blessed object that
 does the L<Kavorka::Sub> role.
 
-   fun foo { }
+   fun foo (:$x, :$y) { }
    
    my $info = Kavorka->info(\&foo);
    
    my $function_name = $info->qualified_name;
-   my @named_params  = grep $_->named, @{$info->signature->params};
+   my @named_params  = $info->signature->named_params;
+   
+   say $named_params[0]->named_names->[0];   # says 'x'
 
 See L<Kavorka::Sub>, L<Kavorka::Signature> and
 L<Kavorka::Signature::Parameter> for further details.
